@@ -1,6 +1,6 @@
 package OpenInteract::Handler::NewUser;
 
-# $Id: NewUser.pm,v 1.8 2002/05/13 12:17:43 lachoy Exp $
+# $Id: NewUser.pm,v 1.9 2002/11/25 14:02:23 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
@@ -8,7 +8,7 @@ use SPOPS::Secure qw( :level :scope );
 use SPOPS::Utility;
 
 @OpenInteract::Handler::NewUser::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::NewUser::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::NewUser::default_method    = 'show';
@@ -79,7 +79,7 @@ sub edit {
     if ( $R->CONFIG->{login}{crypt_password} ) {
         $new_user->{password}   = SPOPS::Utility->crypt_it( $password );
     }
-    $new_user->{removal_date} = $R->user->now( { time => $R->{time} + REMOVAL_TIME } );
+    $new_user->{removal_date} = SPOPS::Utility->now({ time => $R->{time} + REMOVAL_TIME });
     eval { $new_user->save };
 
     # If there was an error, log it and send to the admin (error handler)
@@ -97,9 +97,9 @@ sub edit {
     # Ensure that the user can read/write his/her own record!
 
     eval { $R->user->set_item_security({ class     => $R->user,
-                                         object_id => $new_user->{user_id},
+                                         object_id => $new_user->id,
                                          scope     => SEC_SCOPE_USER,
-                                         scope_id  => $new_user->{user_id},
+                                         scope_id  => $new_user->id,
                                          level     => SEC_LEVEL_WRITE }) };
 
     # Log the failed security set, if it happens...
@@ -113,8 +113,8 @@ sub edit {
 
     else {
         $new_user->log_action_enter( 'create',
-                                     $new_user->{user_id},
-                                     $new_user->{user_id} );
+                                     $new_user->id,
+                                     $new_user->id );
     }
 
     # If that worked ok, send the user an email with the password created
@@ -181,8 +181,6 @@ sub _validate_email {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::Handler::NewUser - Display form for and process new user requests
@@ -240,5 +238,3 @@ it under the same terms as Perl itself.
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
-
-=cut
